==> dde-session-shell_5.4.13.orig.tar.xz: dde-session-shell-5.4.13/translations/dde-session-shell_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>ContentWidget</name>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="357"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja desligado; e forçar o desligamento, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="358"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="363"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="367"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="371"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="375"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para fechar o programa, clique em Cancelar e feche o programa.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="362"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja reiniciado; e forçar a reinicialização, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="366"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja suspenso; e forçar a suspensão, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="370"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja hibernado; e forçar a hibernação, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="374"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador encerre a sessão; e forçar o encerramento da sessão, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="391"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="435"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="460"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="614"/>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="394"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="437"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="463"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="617"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="397"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="620"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="399"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="623"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="401"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="466"/>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="629"/>
        <source>Log out</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="461"/>
        <source>Are you sure you want to shut down?</source>
        <translation>Desligar?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="464"/>
        <source>Are you sure you want to reboot?</source>
        <translation>Reiniciar?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="467"/>
        <source>Are you sure you want to log out?</source>
        <translation>Sair?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="626"/>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="632"/>
        <source>Switch user</source>
        <translation>Alternar Usuário</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/contentwidget.cpp" line="637"/>
        <source>Switch system</source>
        <translation>Alternar Sistema</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="329"/>
        <source>Wrong Password</source>
        <translation>Senha incorreta</translation>
    </message>
    <message>
        <location filename="../src/lightdm-deepin-greeter/greeterworkek.cpp" line="333"/>
        <source>The account or password is not correct. Please enter again.</source>
        <translation>A conta ou senha não está correta; digite novamente.</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <location filename="../src/dde-shutdown/view/inhibitwarnview.cpp" line="90"/>
        <location filename="../src/widgets/inhibitwarnview.cpp" line="90"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="405"/>
        <source>Lock Screen</source>
        <translation>Tela de Bloqueio</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/lockcontent.cpp" line="409"/>
        <source>Failed to lock screen</source>
        <translation>Falha ao bloquear a tela</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="291"/>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>O tempo de verificação da impressão digital expirou; digite a senha</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="309"/>
        <source>Failed to match fingerprint</source>
        <translation>Falha ao coincidir a impressão digital</translation>
    </message>
    <message>
        <location filename="../src/dde-lock/lockworker.cpp" line="339"/>
        <source>Wrong Password</source>
        <translation>Senha incorreta</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="45"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="45"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="130"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="133"/>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Os usuários acima ainda estão conectados e os dados serão perdidos devido ao desligamento. Desligar?</translation>
    </message>
    <message>
        <location filename="../src/dde-shutdown/view/multiuserswarningview.cpp" line="134"/>
        <location filename="../src/widgets/multiuserswarningview.cpp" line="137"/>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Os usuários acima ainda estão conectados e os dados serão perdidos devido à reinicialização. Reiniciar?</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="30"/>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="31"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="172"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="32"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="178"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="33"/>
        <location filename="../src/widgets/shutdownwidget.cpp" line="184"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="190"/>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="196"/>
        <source>Log out</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="202"/>
        <source>Switch user</source>
        <translation>Alternar usuário</translation>
    </message>
    <message>
        <location filename="../src/widgets/shutdownwidget.cpp" line="210"/>
        <source>Switch system</source>
        <translation>Alternar sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <location filename="../src/dde-shutdown/view/systemmonitor.cpp" line="45"/>
        <location filename="../src/widgets/systemmonitor.cpp" line="45"/>
        <source>Start system monitor</source>
        <translation>Monitor de Sistema</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="193"/>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="197"/>
        <source>Account</source>
        <translation>Conta</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="239"/>
        <source>Please enter the account</source>
        <translation>Digite a conta</translation>
    </message>
    <message>
        <location filename="../src/session-widgets/userloginwidget.cpp" line="246"/>
        <source>Please enter the password</source>
        <translation>Digite a senha</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/session-widgets/userloginwidget.cpp" line="338"/>
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Por favor tente novamente após %n minutos</numerusform><numerusform>Por favor tente novamente após %n minuto</numerusform></translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="149"/>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja desligado; e forçar o desligamento, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="150"/>
        <location filename="../src/widgets/warningcontent.cpp" line="155"/>
        <location filename="../src/widgets/warningcontent.cpp" line="159"/>
        <location filename="../src/widgets/warningcontent.cpp" line="163"/>
        <location filename="../src/widgets/warningcontent.cpp" line="167"/>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para fechar o aplicativo, clique em Cancelar e depois feche-o.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="154"/>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja reiniciado; e forçar a reinicialização, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="158"/>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja suspenso; e forçar a suspensão, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="162"/>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja hibernado; e forçar a hibernação, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="166"/>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador encerre a sessão; e forçar o encerramento da sessão, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="182"/>
        <location filename="../src/widgets/warningcontent.cpp" line="235"/>
        <location filename="../src/widgets/warningcontent.cpp" line="267"/>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="185"/>
        <location filename="../src/widgets/warningcontent.cpp" line="237"/>
        <location filename="../src/widgets/warningcontent.cpp" line="270"/>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="188"/>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="190"/>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="192"/>
        <location filename="../src/widgets/warningcontent.cpp" line="273"/>
        <source>Log out</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="268"/>
        <source>Are you sure you want to shut down?</source>
        <translation>Desligar?</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="271"/>
        <source>Are you sure you want to reboot?</source>
        <translation>Reiniciar?</translation>
    </message>
    <message>
        <location filename="../src/widgets/warningcontent.cpp" line="274"/>
        <source>Are you sure you want to log out?</source>
        <translation>Sair?</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.34.orig.tar.xz: dde-session-shell-5.5.34/translations/dde-session-shell_pt_BR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_BR" version="2.1">
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifique a impressão digital</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem-sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou; restam %n tentativas</numerusform><numerusform>A verificação falhou; restam %n tentativas</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou; resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Impressão digital bloqueada; utilize a senha</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem-sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou; restam %n tentativas</numerusform><numerusform>A verificação falhou; restam %n tentativas</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou; resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Senha Incorreta</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tente novamente em 1 minuto</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem-sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou; restam %n tentativas</numerusform><numerusform>A verificação falhou; restam %n tentativas</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou; resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN incorreto</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>A UKey é necessária</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Insira o PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthenticationModule</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificação bem-sucedida</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>A verificação falhou; restam %n tentativas</numerusform><numerusform>A verificação falhou; restam %n tentativas</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>A verificação falhou; resta apenas uma tentativa</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Senha Incorreta</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN incorreto</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>A UKey é necessária</translation>
    </message>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifique a impressão digital</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Senha</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Insira o PIN</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Impressão digital bloqueada; utilize a senha</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Tente novamente em 1 minuto</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Tente novamente em %n minuto(s)</numerusform><numerusform>Tente novamente em %n minuto(s)</numerusform></translation>
    </message>
</context>
<context>
    <name>ContentWidget</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja desligado; e forçar o desligamento, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para fechar o programa, clique em Cancelar e feche o programa.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja reiniciado; e forçar a reinicialização, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja suspenso; e forçar a suspensão, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja hibernado; e forçar a hibernação, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador encerre a sessão; e forçar o encerramento da sessão, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Desligar?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Reiniciar?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Sair?</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Alternar Usuário</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Alternar Sistema</translation>
    </message>
</context>
<context>
    <name>GreeterWorkek</name>
    <message>
        <source>Wrong account</source>
        <translation>Conta incorreta</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Senha Incorreta</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Bloquear Tela</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Falha ao bloquear a tela</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>O tempo de verificação da impressão digital expirou; digite a senha</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Falha ao coincidir a impressão digital</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Os usuários acima ainda estão conectados e os dados serão perdidos devido ao desligamento. Desligar?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Os usuários acima ainda estão conectados e os dados serão perdidos devido à reinicialização. Reiniciar?</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Bloquear</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Alternar usuário</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Alternar sistema</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Monitor de Sistema</translation>
    </message>
</context>
<context>
    <name>UserLoginWidget</name>
    <message>
        <source>Account</source>
        <translation>Conta</translation>
    </message>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifique a impressão digital</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>A senha expirará em %n dias; altere-a em tempo hábil</numerusform><numerusform>A senha expirará em %n dias; altere-a em tempo hábil</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>A senha expirou; altere-a</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja desligado; e forçar o desligamento, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Para fechar o aplicativo, clique em Cancelar e depois feche-o.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja reiniciado; e forçar a reinicialização, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja suspenso; e forçar a suspensão, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador seja hibernado; e forçar a hibernação, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Os processos acima estão impedindo que o computador encerre a sessão; e forçar o encerramento da sessão, poderá causar a perda de dados.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Desligar</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Reiniciar</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Suspender</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernar</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Sair</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Desligar?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Reiniciar?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Sair?</translation>
    </message>
</context>
</TS>
